function runBVPElectrostatic2D01(N,varargin)
close all
[bvp,info]=fc_vfemp1.samples.setBVPElectrostatic2D01(N,'verbose',2,varargin{:});

fprintf('3. Solving 2D Electrostatic BVP\n')
phi=bvp.solve();

fprintf('4. Graphic representations\n');
options_title={'interpreter','latex','fontsize',14};
options_legend={'fontsize',12};

Th=bvp.Th;

figure(1)
Th.plotmesh('legend',true)
axis image;axis off

figure(2)
Th.plotmesh('color',[0.8,0.8,0.8])
hold on;axis image;axis off
Th.plotmesh('d',1,'LineWidth',1.5,'legend',true)
set(legend(),options_legend{:})

figure(3)
Th.plotmesh('d',1,'color',[0,0,0],'legend',false)
hold on;axis image;axis off
Th.plot(phi,'EdgeColor','None')
colorbar
Th.plotiso(phi,'niso',20,'Color','w','LineWidth',1) 
Th.plotmesh('d',1,'color',[0,0,0],'LineWidth',1.5)
shading interp
title('potentiel $\varphi$',options_title{:})

figure(4)
Th.plotmesh('color',[0.85,0.85,0.85])
hold on;axis image;axis off
Th.plotmesh('d',1,'color',[0,0,0])
Th.plotiso(phi,'niso',25,'isocolorbar',true,'format','%.3f');
title('potentiel $\varphi$',options_title{:})

% Computation of the electric field E
Lop=Loperator(2,2,[],[],{-1,0},[]);
Ex=Lop.apply(Th,phi); 
Lop=Loperator(2,2,[],[],{0,-1},[]);
Ey=Lop.apply(Th,phi); 
E=[Ex,Ey]';

figure(5)
Th.plotmesh('d',1,'color',[0,0,0])
hold on;axis image;axis off
[colors,isorange]=Th.plotiso(phi,'niso',25,'isocolorbar',true,'format','%.3f');
Th.plotVectorField(E,'labels',10)
axis image;axis off;
title('potentiel $\varphi$ and electric field $E$',options_title{:})

figure(6)
ENorm=sqrt(Ex.^2+Ey.^2);
Th.plot(ENorm,'EdgeColor','None')
hold on;axis off;axis image;axis off;colorbar
Th.plotiso(ENorm,'niso',20,'Color','w','LineWidth',1) 
Th.plotmesh('d',1,'color',[0,0,0],'LineWidth',1.5)
shading interp
title('Norm of the electric field $E$',options_title{:})

figure(7)
Th.plotmesh('d',1,'color',[0,0,0])
hold on;axis off;axis image;axis off;
Th.plotiso(ENorm,'niso',25,'isocolorbar',true,'format','%.3f');
title('Norm of the electric field $E$',options_title{:})
